@@ -6,9 +6,9 @@ Type annotations for machinelearning service type definitions.
 Usage::
 
     ```python
-    from mypy_boto3_machinelearning.type_defs import AddTagsOutputTypeDef
+    from mypy_boto3_machinelearning.type_defs import AddTagsInputTypeDef
 
-    data: AddTagsOutputTypeDef = {...}
+    data: AddTagsInputTypeDef = {...}
     ```
 """
 import sys
@@ -16,10 +16,15 @@ from datetime import datetime
 from typing import Any, Dict, List
 
 from .literals import (
+    BatchPredictionFilterVariableType,
+    DataSourceFilterVariableType,
     DetailsAttributesType,
     EntityStatusType,
+    EvaluationFilterVariableType,
+    MLModelFilterVariableType,
     MLModelTypeType,
     RealtimeEndpointStatusType,
+    SortOrderType,
     TaggableResourceTypeType,
 )
 
@@ -34,36 +39,60 @@ else:
 
 
 __all__ = (
-    "AddTagsOutputTypeDef",
+    "AddTagsInputTypeDef",
+    "AddTagsOutputResponseTypeDef",
     "BatchPredictionTypeDef",
-    "CreateBatchPredictionOutputTypeDef",
-    "CreateDataSourceFromRDSOutputTypeDef",
-    "CreateDataSourceFromRedshiftOutputTypeDef",
-    "CreateDataSourceFromS3OutputTypeDef",
-    "CreateEvaluationOutputTypeDef",
-    "CreateMLModelOutputTypeDef",
-    "CreateRealtimeEndpointOutputTypeDef",
+    "CreateBatchPredictionInputTypeDef",
+    "CreateBatchPredictionOutputResponseTypeDef",
+    "CreateDataSourceFromRDSInputTypeDef",
+    "CreateDataSourceFromRDSOutputResponseTypeDef",
+    "CreateDataSourceFromRedshiftInputTypeDef",
+    "CreateDataSourceFromRedshiftOutputResponseTypeDef",
+    "CreateDataSourceFromS3InputTypeDef",
+    "CreateDataSourceFromS3OutputResponseTypeDef",
+    "CreateEvaluationInputTypeDef",
+    "CreateEvaluationOutputResponseTypeDef",
+    "CreateMLModelInputTypeDef",
+    "CreateMLModelOutputResponseTypeDef",
+    "CreateRealtimeEndpointInputTypeDef",
+    "CreateRealtimeEndpointOutputResponseTypeDef",
     "DataSourceTypeDef",
-    "DeleteBatchPredictionOutputTypeDef",
-    "DeleteDataSourceOutputTypeDef",
-    "DeleteEvaluationOutputTypeDef",
-    "DeleteMLModelOutputTypeDef",
-    "DeleteRealtimeEndpointOutputTypeDef",
-    "DeleteTagsOutputTypeDef",
-    "DescribeBatchPredictionsOutputTypeDef",
-    "DescribeDataSourcesOutputTypeDef",
-    "DescribeEvaluationsOutputTypeDef",
-    "DescribeMLModelsOutputTypeDef",
-    "DescribeTagsOutputTypeDef",
+    "DeleteBatchPredictionInputTypeDef",
+    "DeleteBatchPredictionOutputResponseTypeDef",
+    "DeleteDataSourceInputTypeDef",
+    "DeleteDataSourceOutputResponseTypeDef",
+    "DeleteEvaluationInputTypeDef",
+    "DeleteEvaluationOutputResponseTypeDef",
+    "DeleteMLModelInputTypeDef",
+    "DeleteMLModelOutputResponseTypeDef",
+    "DeleteRealtimeEndpointInputTypeDef",
+    "DeleteRealtimeEndpointOutputResponseTypeDef",
+    "DeleteTagsInputTypeDef",
+    "DeleteTagsOutputResponseTypeDef",
+    "DescribeBatchPredictionsInputTypeDef",
+    "DescribeBatchPredictionsOutputResponseTypeDef",
+    "DescribeDataSourcesInputTypeDef",
+    "DescribeDataSourcesOutputResponseTypeDef",
+    "DescribeEvaluationsInputTypeDef",
+    "DescribeEvaluationsOutputResponseTypeDef",
+    "DescribeMLModelsInputTypeDef",
+    "DescribeMLModelsOutputResponseTypeDef",
+    "DescribeTagsInputTypeDef",
+    "DescribeTagsOutputResponseTypeDef",
     "EvaluationTypeDef",
-    "GetBatchPredictionOutputTypeDef",
-    "GetDataSourceOutputTypeDef",
-    "GetEvaluationOutputTypeDef",
-    "GetMLModelOutputTypeDef",
+    "GetBatchPredictionInputTypeDef",
+    "GetBatchPredictionOutputResponseTypeDef",
+    "GetDataSourceInputTypeDef",
+    "GetDataSourceOutputResponseTypeDef",
+    "GetEvaluationInputTypeDef",
+    "GetEvaluationOutputResponseTypeDef",
+    "GetMLModelInputTypeDef",
+    "GetMLModelOutputResponseTypeDef",
     "MLModelTypeDef",
     "PaginatorConfigTypeDef",
     "PerformanceMetricsTypeDef",
-    "PredictOutputTypeDef",
+    "PredictInputTypeDef",
+    "PredictOutputResponseTypeDef",
     "PredictionTypeDef",
     "RDSDataSpecTypeDef",
     "RDSDatabaseCredentialsTypeDef",
@@ -77,15 +106,28 @@ __all__ = (
     "ResponseMetadataTypeDef",
     "S3DataSpecTypeDef",
     "TagTypeDef",
-    "UpdateBatchPredictionOutputTypeDef",
-    "UpdateDataSourceOutputTypeDef",
-    "UpdateEvaluationOutputTypeDef",
-    "UpdateMLModelOutputTypeDef",
+    "UpdateBatchPredictionInputTypeDef",
+    "UpdateBatchPredictionOutputResponseTypeDef",
+    "UpdateDataSourceInputTypeDef",
+    "UpdateDataSourceOutputResponseTypeDef",
+    "UpdateEvaluationInputTypeDef",
+    "UpdateEvaluationOutputResponseTypeDef",
+    "UpdateMLModelInputTypeDef",
+    "UpdateMLModelOutputResponseTypeDef",
     "WaiterConfigTypeDef",
 )
 
-AddTagsOutputTypeDef = TypedDict(
-    "AddTagsOutputTypeDef",
+AddTagsInputTypeDef = TypedDict(
+    "AddTagsInputTypeDef",
+    {
+        "Tags": List["TagTypeDef"],
+        "ResourceId": str,
+        "ResourceType": TaggableResourceTypeType,
+    },
+)
+
+AddTagsOutputResponseTypeDef = TypedDict(
+    "AddTagsOutputResponseTypeDef",
     {
         "ResourceId": str,
         "ResourceType": TaggableResourceTypeType,
@@ -116,56 +158,208 @@ BatchPredictionTypeDef = TypedDict(
     total=False,
 )
 
-CreateBatchPredictionOutputTypeDef = TypedDict(
-    "CreateBatchPredictionOutputTypeDef",
+_RequiredCreateBatchPredictionInputTypeDef = TypedDict(
+    "_RequiredCreateBatchPredictionInputTypeDef",
+    {
+        "BatchPredictionId": str,
+        "MLModelId": str,
+        "BatchPredictionDataSourceId": str,
+        "OutputUri": str,
+    },
+)
+_OptionalCreateBatchPredictionInputTypeDef = TypedDict(
+    "_OptionalCreateBatchPredictionInputTypeDef",
+    {
+        "BatchPredictionName": str,
+    },
+    total=False,
+)
+
+
+class CreateBatchPredictionInputTypeDef(
+    _RequiredCreateBatchPredictionInputTypeDef, _OptionalCreateBatchPredictionInputTypeDef
+):
+    pass
+
+
+CreateBatchPredictionOutputResponseTypeDef = TypedDict(
+    "CreateBatchPredictionOutputResponseTypeDef",
     {
         "BatchPredictionId": str,
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-CreateDataSourceFromRDSOutputTypeDef = TypedDict(
-    "CreateDataSourceFromRDSOutputTypeDef",
+_RequiredCreateDataSourceFromRDSInputTypeDef = TypedDict(
+    "_RequiredCreateDataSourceFromRDSInputTypeDef",
+    {
+        "DataSourceId": str,
+        "RDSData": "RDSDataSpecTypeDef",
+        "RoleARN": str,
+    },
+)
+_OptionalCreateDataSourceFromRDSInputTypeDef = TypedDict(
+    "_OptionalCreateDataSourceFromRDSInputTypeDef",
+    {
+        "DataSourceName": str,
+        "ComputeStatistics": bool,
+    },
+    total=False,
+)
+
+
+class CreateDataSourceFromRDSInputTypeDef(
+    _RequiredCreateDataSourceFromRDSInputTypeDef, _OptionalCreateDataSourceFromRDSInputTypeDef
+):
+    pass
+
+
+CreateDataSourceFromRDSOutputResponseTypeDef = TypedDict(
+    "CreateDataSourceFromRDSOutputResponseTypeDef",
     {
         "DataSourceId": str,
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-CreateDataSourceFromRedshiftOutputTypeDef = TypedDict(
-    "CreateDataSourceFromRedshiftOutputTypeDef",
+_RequiredCreateDataSourceFromRedshiftInputTypeDef = TypedDict(
+    "_RequiredCreateDataSourceFromRedshiftInputTypeDef",
+    {
+        "DataSourceId": str,
+        "DataSpec": "RedshiftDataSpecTypeDef",
+        "RoleARN": str,
+    },
+)
+_OptionalCreateDataSourceFromRedshiftInputTypeDef = TypedDict(
+    "_OptionalCreateDataSourceFromRedshiftInputTypeDef",
+    {
+        "DataSourceName": str,
+        "ComputeStatistics": bool,
+    },
+    total=False,
+)
+
+
+class CreateDataSourceFromRedshiftInputTypeDef(
+    _RequiredCreateDataSourceFromRedshiftInputTypeDef,
+    _OptionalCreateDataSourceFromRedshiftInputTypeDef,
+):
+    pass
+
+
+CreateDataSourceFromRedshiftOutputResponseTypeDef = TypedDict(
+    "CreateDataSourceFromRedshiftOutputResponseTypeDef",
     {
         "DataSourceId": str,
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-CreateDataSourceFromS3OutputTypeDef = TypedDict(
-    "CreateDataSourceFromS3OutputTypeDef",
+_RequiredCreateDataSourceFromS3InputTypeDef = TypedDict(
+    "_RequiredCreateDataSourceFromS3InputTypeDef",
+    {
+        "DataSourceId": str,
+        "DataSpec": "S3DataSpecTypeDef",
+    },
+)
+_OptionalCreateDataSourceFromS3InputTypeDef = TypedDict(
+    "_OptionalCreateDataSourceFromS3InputTypeDef",
+    {
+        "DataSourceName": str,
+        "ComputeStatistics": bool,
+    },
+    total=False,
+)
+
+
+class CreateDataSourceFromS3InputTypeDef(
+    _RequiredCreateDataSourceFromS3InputTypeDef, _OptionalCreateDataSourceFromS3InputTypeDef
+):
+    pass
+
+
+CreateDataSourceFromS3OutputResponseTypeDef = TypedDict(
+    "CreateDataSourceFromS3OutputResponseTypeDef",
     {
         "DataSourceId": str,
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-CreateEvaluationOutputTypeDef = TypedDict(
-    "CreateEvaluationOutputTypeDef",
+_RequiredCreateEvaluationInputTypeDef = TypedDict(
+    "_RequiredCreateEvaluationInputTypeDef",
+    {
+        "EvaluationId": str,
+        "MLModelId": str,
+        "EvaluationDataSourceId": str,
+    },
+)
+_OptionalCreateEvaluationInputTypeDef = TypedDict(
+    "_OptionalCreateEvaluationInputTypeDef",
+    {
+        "EvaluationName": str,
+    },
+    total=False,
+)
+
+
+class CreateEvaluationInputTypeDef(
+    _RequiredCreateEvaluationInputTypeDef, _OptionalCreateEvaluationInputTypeDef
+):
+    pass
+
+
+CreateEvaluationOutputResponseTypeDef = TypedDict(
+    "CreateEvaluationOutputResponseTypeDef",
     {
         "EvaluationId": str,
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-CreateMLModelOutputTypeDef = TypedDict(
-    "CreateMLModelOutputTypeDef",
+_RequiredCreateMLModelInputTypeDef = TypedDict(
+    "_RequiredCreateMLModelInputTypeDef",
+    {
+        "MLModelId": str,
+        "MLModelType": MLModelTypeType,
+        "TrainingDataSourceId": str,
+    },
+)
+_OptionalCreateMLModelInputTypeDef = TypedDict(
+    "_OptionalCreateMLModelInputTypeDef",
+    {
+        "MLModelName": str,
+        "Parameters": Dict[str, str],
+        "Recipe": str,
+        "RecipeUri": str,
+    },
+    total=False,
+)
+
+
+class CreateMLModelInputTypeDef(
+    _RequiredCreateMLModelInputTypeDef, _OptionalCreateMLModelInputTypeDef
+):
+    pass
+
+
+CreateMLModelOutputResponseTypeDef = TypedDict(
+    "CreateMLModelOutputResponseTypeDef",
     {
         "MLModelId": str,
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-CreateRealtimeEndpointOutputTypeDef = TypedDict(
-    "CreateRealtimeEndpointOutputTypeDef",
+CreateRealtimeEndpointInputTypeDef = TypedDict(
+    "CreateRealtimeEndpointInputTypeDef",
+    {
+        "MLModelId": str,
+    },
+)
+
+CreateRealtimeEndpointOutputResponseTypeDef = TypedDict(
+    "CreateRealtimeEndpointOutputResponseTypeDef",
     {
         "MLModelId": str,
         "RealtimeEndpointInfo": "RealtimeEndpointInfoTypeDef",
@@ -198,40 +392,75 @@ DataSourceTypeDef = TypedDict(
     total=False,
 )
 
-DeleteBatchPredictionOutputTypeDef = TypedDict(
-    "DeleteBatchPredictionOutputTypeDef",
+DeleteBatchPredictionInputTypeDef = TypedDict(
+    "DeleteBatchPredictionInputTypeDef",
+    {
+        "BatchPredictionId": str,
+    },
+)
+
+DeleteBatchPredictionOutputResponseTypeDef = TypedDict(
+    "DeleteBatchPredictionOutputResponseTypeDef",
     {
         "BatchPredictionId": str,
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-DeleteDataSourceOutputTypeDef = TypedDict(
-    "DeleteDataSourceOutputTypeDef",
+DeleteDataSourceInputTypeDef = TypedDict(
+    "DeleteDataSourceInputTypeDef",
+    {
+        "DataSourceId": str,
+    },
+)
+
+DeleteDataSourceOutputResponseTypeDef = TypedDict(
+    "DeleteDataSourceOutputResponseTypeDef",
     {
         "DataSourceId": str,
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-DeleteEvaluationOutputTypeDef = TypedDict(
-    "DeleteEvaluationOutputTypeDef",
+DeleteEvaluationInputTypeDef = TypedDict(
+    "DeleteEvaluationInputTypeDef",
+    {
+        "EvaluationId": str,
+    },
+)
+
+DeleteEvaluationOutputResponseTypeDef = TypedDict(
+    "DeleteEvaluationOutputResponseTypeDef",
     {
         "EvaluationId": str,
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-DeleteMLModelOutputTypeDef = TypedDict(
-    "DeleteMLModelOutputTypeDef",
+DeleteMLModelInputTypeDef = TypedDict(
+    "DeleteMLModelInputTypeDef",
+    {
+        "MLModelId": str,
+    },
+)
+
+DeleteMLModelOutputResponseTypeDef = TypedDict(
+    "DeleteMLModelOutputResponseTypeDef",
     {
         "MLModelId": str,
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-DeleteRealtimeEndpointOutputTypeDef = TypedDict(
-    "DeleteRealtimeEndpointOutputTypeDef",
+DeleteRealtimeEndpointInputTypeDef = TypedDict(
+    "DeleteRealtimeEndpointInputTypeDef",
+    {
+        "MLModelId": str,
+    },
+)
+
+DeleteRealtimeEndpointOutputResponseTypeDef = TypedDict(
+    "DeleteRealtimeEndpointOutputResponseTypeDef",
     {
         "MLModelId": str,
         "RealtimeEndpointInfo": "RealtimeEndpointInfoTypeDef",
@@ -239,8 +468,17 @@ DeleteRealtimeEndpointOutputTypeDef = TypedDict(
     },
 )
 
-DeleteTagsOutputTypeDef = TypedDict(
-    "DeleteTagsOutputTypeDef",
+DeleteTagsInputTypeDef = TypedDict(
+    "DeleteTagsInputTypeDef",
+    {
+        "TagKeys": List[str],
+        "ResourceId": str,
+        "ResourceType": TaggableResourceTypeType,
+    },
+)
+
+DeleteTagsOutputResponseTypeDef = TypedDict(
+    "DeleteTagsOutputResponseTypeDef",
     {
         "ResourceId": str,
         "ResourceType": TaggableResourceTypeType,
@@ -248,8 +486,26 @@ DeleteTagsOutputTypeDef = TypedDict(
     },
 )
 
-DescribeBatchPredictionsOutputTypeDef = TypedDict(
-    "DescribeBatchPredictionsOutputTypeDef",
+DescribeBatchPredictionsInputTypeDef = TypedDict(
+    "DescribeBatchPredictionsInputTypeDef",
+    {
+        "FilterVariable": BatchPredictionFilterVariableType,
+        "EQ": str,
+        "GT": str,
+        "LT": str,
+        "GE": str,
+        "LE": str,
+        "NE": str,
+        "Prefix": str,
+        "SortOrder": SortOrderType,
+        "NextToken": str,
+        "Limit": int,
+    },
+    total=False,
+)
+
+DescribeBatchPredictionsOutputResponseTypeDef = TypedDict(
+    "DescribeBatchPredictionsOutputResponseTypeDef",
     {
         "Results": List["BatchPredictionTypeDef"],
         "NextToken": str,
@@ -257,8 +513,26 @@ DescribeBatchPredictionsOutputTypeDef = TypedDict(
     },
 )
 
-DescribeDataSourcesOutputTypeDef = TypedDict(
-    "DescribeDataSourcesOutputTypeDef",
+DescribeDataSourcesInputTypeDef = TypedDict(
+    "DescribeDataSourcesInputTypeDef",
+    {
+        "FilterVariable": DataSourceFilterVariableType,
+        "EQ": str,
+        "GT": str,
+        "LT": str,
+        "GE": str,
+        "LE": str,
+        "NE": str,
+        "Prefix": str,
+        "SortOrder": SortOrderType,
+        "NextToken": str,
+        "Limit": int,
+    },
+    total=False,
+)
+
+DescribeDataSourcesOutputResponseTypeDef = TypedDict(
+    "DescribeDataSourcesOutputResponseTypeDef",
     {
         "Results": List["DataSourceTypeDef"],
         "NextToken": str,
@@ -266,8 +540,26 @@ DescribeDataSourcesOutputTypeDef = TypedDict(
     },
 )
 
-DescribeEvaluationsOutputTypeDef = TypedDict(
-    "DescribeEvaluationsOutputTypeDef",
+DescribeEvaluationsInputTypeDef = TypedDict(
+    "DescribeEvaluationsInputTypeDef",
+    {
+        "FilterVariable": EvaluationFilterVariableType,
+        "EQ": str,
+        "GT": str,
+        "LT": str,
+        "GE": str,
+        "LE": str,
+        "NE": str,
+        "Prefix": str,
+        "SortOrder": SortOrderType,
+        "NextToken": str,
+        "Limit": int,
+    },
+    total=False,
+)
+
+DescribeEvaluationsOutputResponseTypeDef = TypedDict(
+    "DescribeEvaluationsOutputResponseTypeDef",
     {
         "Results": List["EvaluationTypeDef"],
         "NextToken": str,
@@ -275,8 +567,26 @@ DescribeEvaluationsOutputTypeDef = TypedDict(
     },
 )
 
-DescribeMLModelsOutputTypeDef = TypedDict(
-    "DescribeMLModelsOutputTypeDef",
+DescribeMLModelsInputTypeDef = TypedDict(
+    "DescribeMLModelsInputTypeDef",
+    {
+        "FilterVariable": MLModelFilterVariableType,
+        "EQ": str,
+        "GT": str,
+        "LT": str,
+        "GE": str,
+        "LE": str,
+        "NE": str,
+        "Prefix": str,
+        "SortOrder": SortOrderType,
+        "NextToken": str,
+        "Limit": int,
+    },
+    total=False,
+)
+
+DescribeMLModelsOutputResponseTypeDef = TypedDict(
+    "DescribeMLModelsOutputResponseTypeDef",
     {
         "Results": List["MLModelTypeDef"],
         "NextToken": str,
@@ -284,8 +594,16 @@ DescribeMLModelsOutputTypeDef = TypedDict(
     },
 )
 
-DescribeTagsOutputTypeDef = TypedDict(
-    "DescribeTagsOutputTypeDef",
+DescribeTagsInputTypeDef = TypedDict(
+    "DescribeTagsInputTypeDef",
+    {
+        "ResourceId": str,
+        "ResourceType": TaggableResourceTypeType,
+    },
+)
+
+DescribeTagsOutputResponseTypeDef = TypedDict(
+    "DescribeTagsOutputResponseTypeDef",
     {
         "ResourceId": str,
         "ResourceType": TaggableResourceTypeType,
@@ -315,8 +633,15 @@ EvaluationTypeDef = TypedDict(
     total=False,
 )
 
-GetBatchPredictionOutputTypeDef = TypedDict(
-    "GetBatchPredictionOutputTypeDef",
+GetBatchPredictionInputTypeDef = TypedDict(
+    "GetBatchPredictionInputTypeDef",
+    {
+        "BatchPredictionId": str,
+    },
+)
+
+GetBatchPredictionOutputResponseTypeDef = TypedDict(
+    "GetBatchPredictionOutputResponseTypeDef",
     {
         "BatchPredictionId": str,
         "MLModelId": str,
@@ -339,8 +664,29 @@ GetBatchPredictionOutputTypeDef = TypedDict(
     },
 )
 
-GetDataSourceOutputTypeDef = TypedDict(
-    "GetDataSourceOutputTypeDef",
+_RequiredGetDataSourceInputTypeDef = TypedDict(
+    "_RequiredGetDataSourceInputTypeDef",
+    {
+        "DataSourceId": str,
+    },
+)
+_OptionalGetDataSourceInputTypeDef = TypedDict(
+    "_OptionalGetDataSourceInputTypeDef",
+    {
+        "Verbose": bool,
+    },
+    total=False,
+)
+
+
+class GetDataSourceInputTypeDef(
+    _RequiredGetDataSourceInputTypeDef, _OptionalGetDataSourceInputTypeDef
+):
+    pass
+
+
+GetDataSourceOutputResponseTypeDef = TypedDict(
+    "GetDataSourceOutputResponseTypeDef",
     {
         "DataSourceId": str,
         "DataLocationS3": str,
@@ -366,8 +712,15 @@ GetDataSourceOutputTypeDef = TypedDict(
     },
 )
 
-GetEvaluationOutputTypeDef = TypedDict(
-    "GetEvaluationOutputTypeDef",
+GetEvaluationInputTypeDef = TypedDict(
+    "GetEvaluationInputTypeDef",
+    {
+        "EvaluationId": str,
+    },
+)
+
+GetEvaluationOutputResponseTypeDef = TypedDict(
+    "GetEvaluationOutputResponseTypeDef",
     {
         "EvaluationId": str,
         "MLModelId": str,
@@ -388,8 +741,27 @@ GetEvaluationOutputTypeDef = TypedDict(
     },
 )
 
-GetMLModelOutputTypeDef = TypedDict(
-    "GetMLModelOutputTypeDef",
+_RequiredGetMLModelInputTypeDef = TypedDict(
+    "_RequiredGetMLModelInputTypeDef",
+    {
+        "MLModelId": str,
+    },
+)
+_OptionalGetMLModelInputTypeDef = TypedDict(
+    "_OptionalGetMLModelInputTypeDef",
+    {
+        "Verbose": bool,
+    },
+    total=False,
+)
+
+
+class GetMLModelInputTypeDef(_RequiredGetMLModelInputTypeDef, _OptionalGetMLModelInputTypeDef):
+    pass
+
+
+GetMLModelOutputResponseTypeDef = TypedDict(
+    "GetMLModelOutputResponseTypeDef",
     {
         "MLModelId": str,
         "TrainingDataSourceId": str,
@@ -460,8 +832,17 @@ PerformanceMetricsTypeDef = TypedDict(
     total=False,
 )
 
-PredictOutputTypeDef = TypedDict(
-    "PredictOutputTypeDef",
+PredictInputTypeDef = TypedDict(
+    "PredictInputTypeDef",
+    {
+        "MLModelId": str,
+        "Record": Dict[str, str],
+        "PredictEndpoint": str,
+    },
+)
+
+PredictOutputResponseTypeDef = TypedDict(
+    "PredictOutputResponseTypeDef",
     {
         "Prediction": "PredictionTypeDef",
         "ResponseMetadata": "ResponseMetadataTypeDef",
@@ -638,32 +1019,78 @@ TagTypeDef = TypedDict(
     total=False,
 )
 
-UpdateBatchPredictionOutputTypeDef = TypedDict(
-    "UpdateBatchPredictionOutputTypeDef",
+UpdateBatchPredictionInputTypeDef = TypedDict(
+    "UpdateBatchPredictionInputTypeDef",
+    {
+        "BatchPredictionId": str,
+        "BatchPredictionName": str,
+    },
+)
+
+UpdateBatchPredictionOutputResponseTypeDef = TypedDict(
+    "UpdateBatchPredictionOutputResponseTypeDef",
     {
         "BatchPredictionId": str,
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-UpdateDataSourceOutputTypeDef = TypedDict(
-    "UpdateDataSourceOutputTypeDef",
+UpdateDataSourceInputTypeDef = TypedDict(
+    "UpdateDataSourceInputTypeDef",
+    {
+        "DataSourceId": str,
+        "DataSourceName": str,
+    },
+)
+
+UpdateDataSourceOutputResponseTypeDef = TypedDict(
+    "UpdateDataSourceOutputResponseTypeDef",
     {
         "DataSourceId": str,
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-UpdateEvaluationOutputTypeDef = TypedDict(
-    "UpdateEvaluationOutputTypeDef",
+UpdateEvaluationInputTypeDef = TypedDict(
+    "UpdateEvaluationInputTypeDef",
+    {
+        "EvaluationId": str,
+        "EvaluationName": str,
+    },
+)
+
+UpdateEvaluationOutputResponseTypeDef = TypedDict(
+    "UpdateEvaluationOutputResponseTypeDef",
     {
         "EvaluationId": str,
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-UpdateMLModelOutputTypeDef = TypedDict(
-    "UpdateMLModelOutputTypeDef",
+_RequiredUpdateMLModelInputTypeDef = TypedDict(
+    "_RequiredUpdateMLModelInputTypeDef",
+    {
+        "MLModelId": str,
+    },
+)
+_OptionalUpdateMLModelInputTypeDef = TypedDict(
+    "_OptionalUpdateMLModelInputTypeDef",
+    {
+        "MLModelName": str,
+        "ScoreThreshold": float,
+    },
+    total=False,
+)
+
+
+class UpdateMLModelInputTypeDef(
+    _RequiredUpdateMLModelInputTypeDef, _OptionalUpdateMLModelInputTypeDef
+):
+    pass
+
+
+UpdateMLModelOutputResponseTypeDef = TypedDict(
+    "UpdateMLModelOutputResponseTypeDef",
     {
         "MLModelId": str,
         "ResponseMetadata": "ResponseMetadataTypeDef",
